@@ -1,4 +1,6 @@
 import concurrent.futures
+from concurrent.futures import Future
+from datetime import timedelta
 from typing import *
 
 A1 = TypeVar("A1")
@@ -35,6 +37,9 @@ def par_map_2(
     return fut1.result(), fut2.result()
 
 
+
+
+
 def par_map_3(
     func1: Callable[[], A1],
     func2: Callable[[], A2],
